% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summix.R
\name{summix}
\alias{summix}
\title{Summix: estimating mixture proportions of reference group}
\usage{
summix(data, reference, observed, pi.start = c())
}
\arguments{
\item{data}{a dataframe of the observed and reference allele frequencies for N genetic variants. See data formatting document at \href{https://github.com/hendriau/Summix}{https://github.com/hendriau/Summix} for more information.}

\item{reference}{a character vector of the column names for the reference ancestries.}

\item{observed}{a character value that is the column name for the observed group.}

\item{pi.start}{length K numeric vector of the starting guess for the ancestry proportions. If not specified, this defaults to 1/K where K is the number of reference ancestry groups.}
}
\value{
data frame with the following columns

objective: least square value at solution

iterations: number of iterations for SLSQP algorithm

time: time in seconds of SLSQP algorithm

filtered: number of SNPs not used in estimation due to missing values

K columns of mixture proportions of reference ancestry groups input into the function
}
\description{
Summix: estimating mixture proportions of reference groups from large (N SNPs>10,000) genetic AF data
}
\examples{
# load the data
data("ancestryData")

# Estimate 5 reference ancestry proportion values for the gnomAD African/African American group
# using a starting guess of .2 for each ancestry proportion.
summix( data = ancestryData, 
    reference=c("ref_AF_afr_1000G", 
        "ref_AF_eur_1000G", 
        "ref_AF_sas_1000G", 
        "ref_AF_iam_1000G", 
        "ref_AF_eas_1000G"), 
    observed="gnomad_AF_afr", 
    pi.start = c(.2, .2, .2, .2, .2) )

}
\seealso{
\code{\link{adjAF}} for adjusting allele frequencies and \url{https://github.com/hendriau/Summix} for further documentation. \code{\link[nloptr]{slsqp}} function in the nloptr package for further details on Sequential Quadratic Programming \url{https://www.rdocumentation.org/packages/nloptr/versions/1.2.2.2/topics/slsqp}
}
\author{
Gregory Matesi, \email{gregory.matesi@ucdenver.edu}

Audrey Hendricks, \email{audrey.hendricks@ucdenver.edu}
}
\keyword{admixture,}
\keyword{distribution,}
\keyword{genetics,}
\keyword{mixture}
\keyword{population}
\keyword{stratification}
